@@ -18,12 +18,12 @@
 import contextlib
 import os
 
-import testtools
 import mock
+import testtools
 
 from troveclient import base
-from troveclient.openstack.common.apiclient import exceptions
 from troveclient import common
+from troveclient.openstack.common.apiclient import exceptions
 from troveclient import utils
 
 """
@@ -87,10 +87,6 @@ class ManagerTest(testtools.TestCase):
 
         # no cache object, nothing should happen
         manager.write_to_completion_cache("non-exist", "val")
-
-        def side_effect_func(val):
-            return val
-
         manager._mock_cache = mock.Mock()
         manager._mock_cache.write = mock.Mock(return_value=None)
         manager.write_to_completion_cache("mock", "val")
@@ -214,9 +210,6 @@ class ManagerListTest(ManagerTest):
     def tearDown(self):
         super(ManagerListTest, self).tearDown()
 
-    def obj_class(self, res, loaded=True):
-        return res
-
     def test_list_with_body_none(self):
         body = None
         l = self.manager._list("url", self.response_key, obj_class, body)
@@ -279,9 +272,14 @@ class MangerPaginationTests(ManagerTest):
 
         def side_effect(url):
             if url == self.url:
-                return (None, self.body)
-            if url == self.next_url:
-                return (None, self.next_body)
+                return None, self.body
+            # In python 3 the order in the dictionary is not constant
+            # between runs. So we cant rely on the URL params to be
+            # in the same order
+            if ('marker=%s' % self.marker in url and
+                    'limit=%s' % self.limit in url):
+                self.next_url = url
+                return None, self.next_body
 
         self.manager.api.client.get = mock.Mock(side_effect=side_effect)
 
@@ -291,20 +289,20 @@ class MangerPaginationTests(ManagerTest):
     def test_pagination(self):
         resp = self.manager._paginated(self.url, self.response_key)
         self.manager.api.client.get.assert_called_with(self.url)
-        self.assertEqual(resp.items[0].foo, 'p1')
-        self.assertEqual(resp.items[1].foo, 'p2')
-        self.assertEqual(resp.next, self.marker)
-        self.assertEqual(resp.links, self.links)
+        self.assertEqual('p1', resp.items[0].foo)
+        self.assertEqual('p2', resp.items[1].foo)
+        self.assertEqual(self.marker, resp.next)
+        self.assertEqual(self.links, resp.links)
         self.assertTrue(isinstance(resp, common.Paginated))
 
     def test_pagination_next(self):
         resp = self.manager._paginated(self.url, self.response_key,
                                        limit=self.limit, marker=self.marker)
         self.manager.api.client.get.assert_called_with(self.next_url)
-        self.assertEqual(resp.items[0].foo, 'p3')
-        self.assertEqual(resp.items[1].foo, 'p4')
-        self.assertEqual(resp.next, None)
-        self.assertEqual(resp.links, [])
+        self.assertEqual('p3', resp.items[0].foo)
+        self.assertEqual('p4', resp.items[1].foo)
+        self.assertEqual(None, resp.next)
+        self.assertEqual([], resp.links)
         self.assertTrue(isinstance(resp, common.Paginated))
 
     def test_pagination_error(self):
@@ -359,23 +357,23 @@ class FindResourceTestCase(testtools.TestCase):
 
     def test_find_by_integer_id(self):
         output = utils.find_resource(self.manager, 1234)
-        self.assertEqual(output, self.manager.get('1234'))
+        self.assertEqual(self.manager.get('1234'), output)
 
     def test_find_by_str_id(self):
         output = utils.find_resource(self.manager, '1234')
-        self.assertEqual(output, self.manager.get('1234'))
+        self.assertEqual(self.manager.get('1234'), output)
 
     def test_find_by_uuid(self):
         output = utils.find_resource(self.manager, UUID)
-        self.assertEqual(output, self.manager.get(UUID))
+        self.assertEqual(self.manager.get(UUID), output)
 
     def test_find_by_str_name(self):
         output = utils.find_resource(self.manager, 'entity_one')
-        self.assertEqual(output, self.manager.get('1234'))
+        self.assertEqual(self.manager.get('1234'), output)
 
     def test_find_by_str_displayname(self):
         output = utils.find_resource(self.manager, 'entity_three')
-        self.assertEqual(output, self.manager.get('4242'))
+        self.assertEqual(self.manager.get('4242'), output)
 
 
 class ResourceTest(testtools.TestCase):
@@ -455,8 +453,8 @@ class ResourceTest(testtools.TestCase):
         robj._add_details(info_)
         self.assertEqual(info_["test_attr"], robj.__getattr__("test_attr"))
 
-        #TODO(dmakogon): looks like causing infinite recursive calls
-        #robj.__getattr__("test_non_exist_attr")
+        # TODO(dmakogon): looks like causing infinite recursive calls
+        # robj.__getattr__("test_non_exist_attr")
 
     def test___repr__(self):
         robj = self.get_mock_resource_obj()
@@ -472,7 +470,7 @@ class ResourceTest(testtools.TestCase):
         manager.get = None
 
         robj.manager = object()
-        robj.get()
+        robj._get()
 
         manager = mock.Mock()
         robj.manager = mock.Mock()
@@ -481,45 +479,34 @@ class ResourceTest(testtools.TestCase):
         new = mock.Mock()
         new._info = {"name": "test-human-id", "test_attr": 5}
         robj.manager.get = mock.Mock(return_value=new)
-        robj.get()
+        robj._get()
         self.assertEqual("test-human-id", robj.name)
         self.assertEqual(5, robj.test_attr)
 
-    def tes___eq__(self):
+    def test___eq__(self):
         robj = self.get_mock_resource_obj()
         other = base.Resource()
 
         info_ = {"name": "test-human-id", "test_attr": 5}
         robj._info = info_
         other._info = {}
-        self.assertNotTrue(robj.__eq__(other))
-
-        robj._info = info_
-        self.assertTrue(robj.__eq__(other))
+        self.assertFalse(robj.__eq__(other))
 
         robj.id = "rid"
         other.id = "oid"
-        self.assertNotTrue(robj.__eq__(other))
+        self.assertFalse(robj.__eq__(other))
 
         other.id = "rid"
         self.assertTrue(robj.__eq__(other))
 
         # not instance of the same class
         other = mock.Mock()
-        self.assertNotTrue(robj.__eq__(other))
+        self.assertEqual(robj.__eq__(other), NotImplemented)
 
     def test_is_loaded(self):
         robj = self.get_mock_resource_obj()
         robj._loaded = True
-        self.assertTrue(robj.is_loaded())
+        self.assertTrue(robj.is_loaded)
 
         robj._loaded = False
-        self.assertFalse(robj.is_loaded())
-
-    def test_set_loaded(self):
-        robj = self.get_mock_resource_obj()
-        robj.set_loaded(True)
-        self.assertTrue(robj._loaded)
-
-        robj.set_loaded(False)
-        self.assertFalse(robj._loaded)
+        self.assertFalse(robj.is_loaded)
